@@ -15,25 +15,25 @@
 #' error analysis
 #' @examples theta <- c(0.19729, 0.34870, 0.61475, 0.74324, 0.88544, 0.89007, 0.91067, 0.91067, 0.96114)
 #' @examples Ce <- c(0.01353, 0.04648, 0.13239, 0.27714, 0.41600, 0.63607, 0.80435, 1.10327, 1.58223)
-#' @examples floryhugginsanalysis(theta, Ce)
+#' @examples floryhugginsanalysis(Ce, theta)
 #' @author Jemimah Christine L. Mesias
 #' @author Chester C. Deocaris
 #' @references Flory, P. J. (1971). Principles of polymer chemistry. Cornell Univ.Pr.
-#' @references Foo, K. Y., &amp; Hameed, B. H. (2009, September 13).
+#' @references Foo, K. Y., and Hameed, B. H. (2009, September 13).
 #' <doi:10.1016/j.cej.2009.09.013> Insights into the modeling of adsorption isotherm
 #' systems. Chemical Engineering Journal.
 #' @export
 #'
 
 # Building the Flory-Huggins isotherm nonlinear form
-floryhugginsanalysis <- function(theta, Ce){
+floryhugginsanalysis <- function(Ce, theta){
 
   x <- theta
-  y <- 1/Ce
+  y <- Ce
   data <- data.frame(x, y)
 
 # Flory-Huggins isotherm nonlinear equation
-  fit1 <- y ~ (1/x)*(KFH*(1-x)^nFH)
+  fit1 <- y ~ x/(KFH*(1-x)^nFH)
 
 # Setting of starting values
   start1 <- list(KFH = 100 , nFH = 1)
@@ -72,6 +72,9 @@ floryhugginsanalysis <- function(theta, Ce){
   a <- errors(y)
   print(a)
 
+  rsqq <- lm(theta~predict(fit2))
+  print(summary(rsqq))
+
   # Graphical representation of the Flory-Huggins isotherm model
 
   ### Predicted parameter values
@@ -79,15 +82,15 @@ floryhugginsanalysis <- function(theta, Ce){
   pars_KFH <- parsFloryHuggins[1L];
   pars_nFH <- parsFloryHuggins[2L];
 
-  rhs <- function(x) ((1/x)*(pars_KFH *(1-x)^pars_nFH))
+  rhs <- function(x) (x/(pars_KFH*(1-x)^pars_nFH))
 
   #### Plot details
   ggplot2::theme_set(ggplot2::theme_bw(10))
   ggplot2::ggplot(data, ggplot2::aes(x = x, y = y)) + ggplot2::geom_point(color ="#3498DB" ) +
     ggplot2::geom_function(color = "#D35400", fun = rhs ) +
     ggplot2::labs(x = expression(paste(theta)),
-         y = "1/Ce",
+         y = "Ce",
          title = "Flory-Huggins Isotherm Nonlinear Model",
-         caption = "PUPAIM 0.3.0") +
-    ggplot2::theme(plot.title=ggplot2::element_text(hjust = 0.5))
+         caption = "PUPAIM") +
+    ggplot2::theme(plot.title=ggplot2::element_text(hjust = 0.5)) + ggplot2::coord_flip()
 }
