@@ -16,19 +16,19 @@
 #' @examples theta <- c(0.19729, 0.34870, 0.61475, 0.74324, 0.88544, 0.89007, 0.91067, 0.91067, 0.96114)
 #' @examples Ce <- c(0.01353, 0.04648, 0.13239, 0.27714, 0.41600, 0.63607, 0.80435, 1.10327, 1.58223)
 #' @examples Temp <- 298
-#' @examples fowlerguggenheimanalysis(theta,Ce,Temp)
+#' @examples fowlerguggenheimanalysis(Ce,theta,Temp)
 #' @author Jemimah Christine L. Mesias
 #' @author Chester C. Deocaris
 #' @references Fowler, R. H. and Guggenheim, E. A. (1939) Statistical
 #' Thermodynamics, Cambridge University Press, London, England.
-#' @references Foo, K. Y., &amp; Hameed, B. H. (2009, September 13).
+#' @references Foo, K. Y., and; Hameed, B. H. (2009, September 13).
 #' <doi:10.1016/j.cej.2009.09.013> Insights into the modeling of adsorption isotherm
 #' systems. Chemical Engineering Journal.
 #' @export
 #'
 
 # Building the Fowler-Guggenheim isotherm nonlinear form
-fowlerguggenheimanalysis <- function(theta, Ce, Temp){
+fowlerguggenheimanalysis <- function(Ce,theta,Temp){
 
   x <- theta
   y <- Ce
@@ -77,6 +77,9 @@ fowlerguggenheimanalysis <- function(theta, Ce, Temp){
   hga <- errors(y)
   print(hga)
 
+  rsqq <- lm(theta~predict(fit2))
+  print(summary(rsqq))
+
   # Graphical representation of the Fowler-Guggenheim isotherm model
 
   ### Predicted parameter values
@@ -91,9 +94,9 @@ fowlerguggenheimanalysis <- function(theta, Ce, Temp){
   ggplot2::ggplot(data, ggplot2::aes(x = x, y = y)) + ggplot2::geom_point(color ="#3498DB" ) +
     ggplot2::geom_function(color = "#D35400", fun = rhs ) +
     ggplot2::labs(x = expression(paste(theta)),
-         y = "Qe",
+         y = "Ce",
          title = "Fowler-Guggenheim Isotherm Nonlinear Model",
-         caption = "PUPAIM 0.3.0") +
-    ggplot2::theme(plot.title=ggplot2::element_text(hjust=0.5))
+         caption = "PUPAIM") +
+    ggplot2::theme(plot.title=ggplot2::element_text(hjust=0.5)) + ggplot2::coord_flip()
 }
 
