@@ -69,6 +69,9 @@ redlichpetersonanalysis <- function(Ce, Qe){
     }
     a <- errors(y)
     print(a)
+    
+    rsqq <- lm(Qe~predict(fit2))
+    print(summary(rsqq))
 
 # Graphical representation of the Redlich-Peterson isotherm model
 
@@ -87,6 +90,6 @@ redlichpetersonanalysis <- function(Ce, Qe){
       ggplot2::labs(x = "Ce",
            y = "Qe",
            title = "Redlich-Peterson Isotherm Nonlinear Model",
-           caption = "PUPAIM 0.3.0") +
+           caption = "PUPAIM") +
       ggplot2::theme(plot.title=ggplot2::element_text(hjust = 0.5))
 }
